summaryrefslogtreecommitdiff
path: root/gdk/gdkdisplayprivate.h
diff options
context:
space:
mode:
authorBenjamin Otte <otte@redhat.com>2018-04-12 16:48:31 +0200
committerBenjamin Otte <otte@redhat.com>2018-04-24 23:16:12 +0200
commit813e9c95fb6b01fda416701bf4235e8518cf207c (patch)
tree71a0d0747961079ad18c30d75e90b6f6e9f30153 /gdk/gdkdisplayprivate.h
parenta83487a0c4e57063f02f7e3edecb2af9194d6c29 (diff)
downloadgtk+-813e9c95fb6b01fda416701bf4235e8518cf207c.tar.gz
gdk: Add Cairo context implementations for all backends
And make the GdkCairoContext as abstract. The idea of this and thje following commits is to get rid of all Cairo code in gdksurface.c (and $backend/gdksurface-$backend.c) by moving that code into the Cairo context files. In particular, the GdkSurfaceClass.begin_frame/end_frame() functions (which are currently exclusively used by the Cairo code should end up being moved to GdkDrawContextClass.begin/end_frame(). This has multiple benefits: 1. It unifies code between the different drawing contexts. GL lives in GLContext, Vulkan in VulkanContext and Cairo in CairoContext. In turn, this makes it way easier to reason about what's going on in surface-specific code. Currently pretty much all backends do things wrong when they want to sync to drawing or to the frame clock. 2. It makes the API of GdkSurface smaller. No drawing code (apart from creating the contexts) needs to remain. 3. It confines Cairo to the Drawcontext, thereby making it way more obvious when backends are still using it in situations where it may now conflict with OpenGL (like when doing the dnd failed animation or in the APIs that I'm removing in this branch). 4. We have 2 very different types of Cairo contexts: The X/win32 model, where we have a natively supported Cairo backend but do double buffering ourselves and use similar surfaces and the Wayland/Broadway model where we use image surfaces without any Cairo backend support and have to submit the buffers manually. By not sharing code between those 2 versions, we can make the actual code way smaller. We also get around the need to create 1x1 image surfaces in the Wayland backend where we pretend there's a native Cairo surface.
Diffstat (limited to 'gdk/gdkdisplayprivate.h')
-rw-r--r--gdk/gdkdisplayprivate.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/gdk/gdkdisplayprivate.h b/gdk/gdkdisplayprivate.h
index 579f266bf1..ac873281b5 100644
--- a/gdk/gdkdisplayprivate.h
+++ b/gdk/gdkdisplayprivate.h
@@ -114,7 +114,8 @@ struct _GdkDisplayClass
{
GObjectClass parent_class;
- GType surface_type; /* type for native surfaces for this display, set in class_init */
+ GType surface_type; /* type for native surfaces for this display, set in class_init */
+ GType cairo_context_type; /* type for GdkCairoContext, must be set */
GType vk_context_type; /* type for GdkVulkanContext, must be set if vk_extension_name != NULL */
const char *vk_extension_name; /* Name of required windowing vulkan extension or %NULL (default) if Vulkan isn't supported */